@@ -45,6 +45,6 @@ fi
 cd ./api && go build -o ../output/manager-api -ldflags "${GOLDFLAGS}" ./main.go && cd ..
 
 cp ./api/conf/schema.json ./output/conf/schema.json
-cp ./api/conf/conf.yaml ./output/conf/conf.yaml
+cp ./api/conf/conf*.yaml ./output/conf/
 
 echo "Build the Manager API successfully"
