@@ -20,7 +20,7 @@ import (
 	"fmt"
 	"path/filepath"
 
-	"github.com/gin-contrib/pprof"
+	// "github.com/gin-contrib/pprof"
 	"github.com/gin-contrib/static"
 	"github.com/gin-gonic/gin"
 
@@ -93,7 +93,7 @@ func SetUpRouter() *gin.Engine {
 		h.ApplyRoute(r)
 	}
 
-	pprof.Register(r)
+	// pprof.Register(r)
 
 	return r
 }
