@@ -137,7 +137,7 @@ var _ = ginkgo.Describe("create service without plugin", func() {
 	})
 	ginkgo.It("batch test /server_port api", func() {
 		time.Sleep(time.Duration(500) * time.Millisecond)
-		res := base.BatchTestServerPort(18)
+		res := base.BatchTestServerPort(18, nil, "")
 		gomega.Expect(res["1980"]).Should(gomega.Equal(3))
 		gomega.Expect(res["1981"]).Should(gomega.Equal(6))
 		gomega.Expect(res["1982"]).Should(gomega.Equal(9))
